@@ -25,10 +25,8 @@ class BackendProxy(object):
         try:
             response = self.requests.get(SLRoutes.build_session_v2(build_session_id))
             response.raise_for_status()
-            response = response.json()
-            build_session_data = BuildSessionData(response["appName"], response["buildName"], response["branchName"],
-                                                  response["buildSessionId"], additional_params=response.get("additionalParams"))
-            return build_session_data
+            build_session_dict = response.json()
+            return self._create_build_session_data(build_session_dict)
         except HTTPError as e:
             if (e.response.status_code == 404):
                 log.error("Server returned 404 (Not Found) for build session id %s. " % build_session_id)
@@ -195,3 +193,18 @@ class BackendProxy(object):
                test_recommendations.get(TEST_RECOMMENDATION.RSS) and\
                test_recommendations[TEST_RECOMMENDATION.RSS].lower() == TEST_RECOMMENDATION.RSS_NOT_READY
 
+    def get_build_session_from_labid(self, labid):
+        url = SLRoutes.lab_ids_active_build_session_v1(labid)
+        try:
+            response = self.requests.get(url)
+            response.raise_for_status()
+            build_session_dict = response.json()
+            return self._create_build_session_data(build_session_dict)
+        except Exception as e:
+            log.warning("Failed getting active build session from lab id: %s. Error: %s" % (labid, str(e)))
+            return None
+
+    def _create_build_session_data(self, build_session_dict):
+        return BuildSessionData(build_session_dict["appName"], build_session_dict["buildName"],
+                                build_session_dict["branchName"], build_session_dict["buildSessionId"],
+                                additional_params=build_session_dict.get("additionalParams"))
