@@ -6,8 +6,10 @@ from python_agent.test_listener.executors.test_frameworks.agent_execution import
 
 if sys.version_info >= (2, 7):
     from python_agent.test_listener.integrations.unittest_helper import main as unittest_main
+    from python_agent.test_listener.integrations.unittest_helper import unittest
 else:
     from python_agent.test_listener.integrations.unittest_26_helper import main as unittest_main
+    from python_agent.test_listener.integrations.unittest_26_helper import unittest
 
 log = logging.getLogger(__name__)
 
@@ -23,4 +25,7 @@ class Unittest2AgentExecution(AgentExecution):
         # we're appending the current working directory for customers running unittest using: "python -m unit2"
         # since running it like that adds current working directory to sys.path
         sys.path.insert(0, os.getcwd())
-        unittest_main(["unit2"] + list(self.args))
+        if self.config_data.isDisabled:
+            unittest.main(module=None, argv=["unit2"] + list(self.args))
+        else:
+            unittest_main(["unit2"] + list(self.args))
